@@ -1,9 +1,18 @@
+#' @keywords internal
+"_PACKAGE"
+
+## usethis namespace: start
+## usethis namespace: end
+NULL
+
+
+
 #' sfdct.
 #'
 #' Triangulate simple features including the input edges as constraints, rather than
 #' being bounded to the convex hull.
 #'
-#' @name sfdct
+#' @name sfdct-package
 #' @docType package
 NULL
 
