@@ -27,11 +27,6 @@ test_that("bowtie is fixed", {
 })
 
 test_that("Square with wrong orientation", {
-  skip_on_cran()  ## skipped in 0.1.0 because new GEOS on CRAN debian
-  #══ Failed tests ════════════════════════════════════════════════════════════════
-  #── Failure (test-prepair-benchmarks.R:41:3): Square with wrong orientation ─────
-  #sf::st_as_text(st_geometry(fix_wkt(wkt))) == wkt is not FALSE
-
   wkt <- wo_wkt
   context("st_is_valid does not care about orientation")
   ##expect_warning(the_test <- is_valid_wkt(wkt), "Self-intersection")
@@ -43,10 +38,11 @@ test_that("Square with wrong orientation", {
   context(" round-trip is identical")
   expect_true(sf::st_as_text( st_geometry(from_wkt(wkt))) == wkt)
   context(" round-trip after fix is a different string")
-  if (sf::sf_extSoftVersion()["GEOS"] < "3.9.0") {
+  if (utils::compareVersion(sf::sf_extSoftVersion()["GEOS"],  "3.9.0") < 1L) {
     ## changed in 3.9.0 https://github.com/hypertidy/sfdct/issues/13
    expect_false(sf::st_as_text( st_geometry(fix_wkt(wkt))) == wkt)
   }
+
 })
 
 test_that("Inner ring with one edge sharing part of an edge of the outer ring:", {
